"""Manage documentation configuration files.

Provide MkDocs configuration with Material theme, dark/light mode toggle,
navigation (Home, API), search, mermaid diagrams, and mkdocstrings for
Google-style docstring API documentation.

Modules:
    `mkdocs`: `mkdocs.yml` configuration management.

See Also:
    MkDocs: https://www.mkdocs.org/
    Material for MkDocs: https://squidfunk.github.io/mkdocs-material/
    mkdocstrings: https://mkdocstrings.github.io/
"""
